@@ -466,6 +466,8 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
   transparentIndex = ReadBlobByte(image);
   compressionType = ReadBlobByte(image);
   (void) ReadBlobMSBShort(image); /* pad */
+  if (EOFBlob(image))
+    ThrowReaderException(CorruptImageError,UnexpectedEndOfFile,image);
 
   (void) LogMagickEvent(CoderEvent,GetMagickModule(),
                         "Size=%lux%lu, bytes_per_row=%lu, flags=%lu, bits_per_pixel=%lu",
@@ -494,6 +496,8 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
         (void) ReadBlobMSBLong(image); /* size */
       else
         (void) ReadBlobMSBShort(image); /* size */
+      if (EOFBlob(image))
+        ThrowReaderException(CorruptImageError,UnexpectedEndOfFile,image);
     }
   else  /* is color */
     if(bits_per_pixel == 8)
@@ -510,6 +514,8 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
                 image->colormap[index].red = ScaleCharToQuantum(ReadBlobByte(image));
                 image->colormap[index].green = ScaleCharToQuantum(ReadBlobByte(image));
                 image->colormap[index].blue = ScaleCharToQuantum(ReadBlobByte(image));
+                if (EOFBlob(image))
+                  ThrowReaderException(CorruptImageError,UnexpectedEndOfFile,image);
               }
           }
         for(; i < (long) (1L << bits_per_pixel); i++)
@@ -530,6 +536,8 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
             image->colormap[index].red = ScaleCharToQuantum(PalmPalette[i][0]);
             image->colormap[index].green = ScaleCharToQuantum(PalmPalette[i][1]);
             image->colormap[index].blue = ScaleCharToQuantum(PalmPalette[i][2]);
+            if (EOFBlob(image))
+              ThrowReaderException(CorruptImageError,UnexpectedEndOfFile,image);
           }
       }
 
@@ -598,7 +606,7 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
       q = SetImagePixels(image, 0, y, image->columns, 1);
       if (q == (PixelPacket *) NULL)
         break;
-      indexes=GetIndexes(image);
+      indexes=AccessMutableIndexes(image);
       if(bits_per_pixel == 16)
         {
           if (image->columns > 2*bytes_per_row)
@@ -638,6 +646,8 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
           if (!SyncImagePixels(image))
             break;
         }
+      if (EOFBlob(image))
+        ThrowReaderException(CorruptImageError,UnexpectedEndOfFile,image);
     }
 
   if(flags & PALM_HAS_TRANSPARENCY_FLAG)
@@ -689,8 +699,9 @@ ModuleExport void RegisterPALMImage(void)
   entry->encoder=(EncoderHandler) WritePALMImage;
   entry->adjoin=False;
   entry->seekable_stream=True;
-  entry->description=AcquireString("Palm pixmap");
-  entry->module=AcquireString("PALM");
+  entry->description="Palm pixmap";
+  entry->module="PALM";
+  entry->coder_class=UnstableCoderClass;
   (void) RegisterMagickInfo(entry);
 }
 
@@ -914,7 +925,7 @@ static unsigned int WritePALMImage(const ImageInfo *image_info,Image *image)
           for(y = 0; y < (long) image->rows; y++)
             {
               p = GetImagePixels(image, 0, y, image->columns, 1);
-              indexes=GetIndexes(image);
+              indexes=AccessMutableIndexes(image);
               for(x = 0; x < (long) image->columns; x++)
                 indexes[x] = FindColor(&image->colormap[indexes[x]]);
             }
@@ -936,7 +947,7 @@ static unsigned int WritePALMImage(const ImageInfo *image_info,Image *image)
       p=GetImagePixels(image,0,y,image->columns,1);
       if (p == (PixelPacket *) NULL)
         break;
-      indexes=GetIndexes(image);
+      indexes=AccessMutableIndexes(image);
       if(bits_per_pixel == 16)
         {
           for (x=0; x < (int) image->columns; x++)
